@@ -112,8 +112,8 @@ public:
 		return this->find(sourceName) != this->end();
 	}
 
-	std::string getSourceName(std::string const& destinationName) {
-		for (std::map<std::string, std::string>::iterator iter = this->begin(); iter != this->end(); iter++) {
+	std::string getSourceName(std::string const& destinationName) const {
+		for (std::map<std::string, std::string>::const_iterator iter = this->begin(); iter != this->end(); iter++) {
 			if (iter->second == destinationName) {
 				return iter->first;
 			}
@@ -129,6 +129,14 @@ public:
 		return this->_newSources;
 	}
 
+	bool hasUpdateFor(std::string const& scriptName) const {
+		auto sourceName = this->getSourceName(scriptName);
+		if (sourceName == "") {
+			return false;
+		}
+		return std::find(this->_newSources.begin(), this->_newSources.end(), sourceName) != this->_newSources.end();
+	}
+
 	void deleteUpdates() {
 		this->_newSources.clear();
 	}
